/*global define, window*/

define("de_epages/mediagallery/filemanager/preview-view", [
	"jquery",
	"ep",
	"backbone",
	"./item-collection",
	"$dict!../dictionary",
	"$tmpl!./preview-view"
], function ($, ep, Backbone, ItemCollection, mediagalleryDict, template) {
    "use strict";

    /*
     * @dictionary       ep.dict
     *
     * @translation      {Preview}
     *                   {Delete}
     *
     * @dictionary       de_epages.mediagallery.dictionary
     *
     * @translation      {Files}
     *                   {DownloadFile}
     */

    var tFiles = mediagalleryDict.translate("Files"),
        tPreview = mediagalleryDict.translate("Preview"),
        tDelete = mediagalleryDict.translate("Delete"),
        tDownload = mediagalleryDict.translate("DownloadFile"),

        view = Backbone.View.extend({
            tagName: "div",
            className: "ep-mediagallery-preview",
            template: template,

            collection: new ItemCollection(),

            events: {
                "click .ep-mediagallery-deleteItem": "triggerDeleteItems",
                "click .ep-mediagallery-downloadItem": "downloadItem"
            },

            initialize: function () {
                this.collection
	                // when reset is thrown the preview will be cleared
	                .on("reset", this.render, this)
	                // change preview when something in the collection is changed
	                .on("change", this.render, this);
            },

            render: function () {
                var length = this.collection.length,
                    model = this.collection.models[0],
                    data = {},
                    tmpl;

                // translations
                data.tPreview = tPreview;
                data.tDelete = tDelete;
                data.tDownload = tDownload;
                data.name = "";
                data.tFiles = tFiles;

                if (model) {
                    // if one item was selected
                    if (length === 1) {
                        if (model.get("modelType") === "file") {
                            data.name = model.get("name");
                            data.path = (model.get("largePreview") !== undefined) ? model.get("largePreview") : model.get("fullpath");
                            data.downloadPath = model.get("fullpath");
                            data.downloadable = true;
                            data.icon = (model.get("icon") !== undefined) ? true : false;
                        } else {
                            data.name = model.get("data");
                            data.path = ep.config.javascriptRoot + "/de_epages/mediagallery/images/ico_preview.png";
                            data.downloadable = false;
                        }
                    } else {
                    // else: serveral items were selected
                        data.path = ep.config.javascriptRoot + "/de_epages/mediagallery/images/ico_multipleselect.png";
                    }
                    data.type = model.get("metadata").type;
                }

                data.length = length;

                tmpl = this.template(data);
                this.$el.html(tmpl);

                return this;
            },

            clear: function () {
                this.collection.reset();
                this.render();
            },

            triggerDeleteItems: function () {
                this.trigger("deleteItems");
            },

            downloadItem: function () {
                window.open(ep.config.baseUrl + "?ObjectID=" + ep.config.siteId + "&ViewAction=View&ChangeAction=ActionDownloadFile&File=" + this.collection.models[0].get("path"), "Download");
            }
        });

    return view;
});